====================
AstroPhot Docstrings
====================

Here you will find all of the AstroPhot class and method docstrings, built using
markdown formatting. These are useful for understanding the details of a given
model and can also be accessed via the python help command
```help(ap.object)```. For the AstroPhot ``ap.Model`` objects, the docstrings are a
combination of the various base-classes and mixins that make them up. They are
very detailed, but can be a bit awkward in their formatting, the good news is
that a lot of useful information is available there!

.. toctree::
    :maxdepth: 2

    models
    image
    fit
    plots
    utils
    errors
